USE [igops]
GO

DROP VIEW IF EXISTS request_lifecycle_v
GO

CREATE VIEW request_lifecycle_v AS
SELECT
	perm.name AS permissionname,
    perm.unique_permission_id,
    stepuser.display_name AS stepapprovername,
    stepuser.unique_user_id AS stepapproveruserid,
    rras.finish_time AS stepapprovaltime,
    stepuser2.display_name AS statussettername,
    stepuser2.unique_user_id AS statussetteruserid,
    rris.status_time AS statussettime,
    rr.id AS cartid,
    rri.id,
    rras.step AS stepapprovalorder,
    rr.request_status,
    rris.item_approval_status AS stepapproveordenystatus,
    role.name AS rolename,
    ds.name AS appname,
    requser.display_name AS requestusername,
    requser.unique_user_id AS requestuserid,
    rr.creation_time AS requesttime,
    apprvuser.display_name AS approveordenyusername,
    apprvuser.unique_user_id AS approveordenyuserid,
        CASE
            WHEN rras.id IS NULL THEN NULL
            ELSE rri.item_approval_status
        END AS approveordenystatus,
    rri.item_approval_status,
    rri.last_status_update_time AS approveordenytime,
    recipuser.display_name AS recipientusername,
    recipuser.unique_user_id AS recipientuserid,
    rri.add_item AS add_request,
    rri.reason AS item_reason,
    rr.reason AS request_reason,
    rras.finish_comment AS approval_comment,
    cia.change_item_status AS fulfillment_status,
    cia.item_comment AS fulfillment_comment,
    cia.last_updated AS fulfillment_date,
    fufusr.display_name AS fulfillerusername,
    fufusr.unique_user_id AS fulfilleruserid,
        CASE
            WHEN cri.fulfiller_type = 'GROUP' THEN sgrp.name
            WHEN cri.fulfiller_type = 'USER' THEN susr.display_name
            ELSE NULL
        END AS assigned_fulfiller
   FROM resource_request_item rri
     JOIN resource_request rr ON rr.id = rri.resource_request_id
     LEFT JOIN resource_request_item_step rris ON rris.resource_request_item_id = rri.id
     LEFT JOIN suser requser ON requser.unique_user_id = rr.unique_requester_id AND requser.effective = 1
     LEFT JOIN suser recipuser ON recipuser.unique_user_id = rri.unique_recipient_id AND recipuser.effective = 1
     LEFT JOIN spermission perm ON perm.unique_permission_id = rri.unique_item_id AND perm.effective = 1 AND rri.item_type = 'PERMISSION'
     LEFT JOIN role_policy role ON role.unique_policy_id = rri.unique_item_id AND role.deleted = 0 AND rri.item_type = 'TECHNICAL_ROLE'
     LEFT JOIN application app ON CAST(app.id AS NVARCHAR(255)) = rri.unique_item_id AND rri.item_type = 'APPLICATION'
     LEFT JOIN data_source ds ON ds.id = app.id AND ds.deleted = 0
     LEFT JOIN fulfillment_item_combined fic ON fic.id = rri.change_request_item_id
     LEFT JOIN change_request_item cri ON cri.id = fic.id
     LEFT JOIN change_item_action cia ON cia.id = cri.latest_action
     LEFT JOIN suser fufusr ON cia.fulfiller_id = fufusr.unique_user_id AND fufusr.effective = 1
     LEFT JOIN resource_request_approval_step rras ON rras.id = rris.approval_step_id
     LEFT JOIN suser stepuser ON stepuser.unique_user_id = rras.finished_by AND stepuser.effective = 1
     LEFT JOIN suser stepuser2 ON stepuser2.unique_user_id = rris.status_set_by AND stepuser2.effective = 1
     LEFT JOIN suser apprvuser ON apprvuser.unique_user_id = rri.status_changed_by AND apprvuser.effective = 1 AND rras.id IS NOT NULL
     LEFT JOIN sgroup sgrp ON sgrp.unique_group_id = cri.fulfiller AND sgrp.effective = 1
     LEFT JOIN suser susr ON susr.unique_user_id = cri.fulfiller AND susr.effective = 1
GO

GRANT SELECT ON request_lifecycle_v TO ig_report_role
GO
