DROP VIEW IF EXISTS request_lifecycle_v;


CREATE VIEW request_lifecycle_v AS
SELECT
    perm.name AS permissionname,
    perm.unique_permission_id,
    stepuser.display_name AS stepapprovername,
    stepuser.unique_user_id AS stepapproveruserid,
    rras.finish_time AS stepapprovaltime,
    stepuser2.display_name AS statussettername,
    stepuser2.unique_user_id AS statussetteruserid,
    rris.status_time AS statussettime,
    rr.id AS cartid,
    rri.id,
    rras.step AS stepapprovalorder,
    rr.request_status,
    rris.item_approval_status AS stepapproveordenystatus,
    role.name AS rolename,
    ds.name AS appname,
    requser.display_name AS requestusername,
    requser.unique_user_id AS requestuserid,
    rr.creation_time AS requesttime,
    apprvuser.display_name AS approveordenyusername,
    apprvuser.unique_user_id AS approveordenyuserid,
        CASE
            WHEN rras.id IS NULL THEN NULL::character varying
            ELSE rri.item_approval_status
        END AS approveordenystatus,
    rri.item_approval_status,
    rri.last_status_update_time AS approveordenytime,
    recipuser.display_name AS recipientusername,
    recipuser.unique_user_id AS recipientuserid,
    rri.add_item AS add_request,
    rri.reason AS item_reason,
    rr.reason AS request_reason,
    rras.finish_comment AS approval_comment,
    cia.change_item_status AS fulfillment_status,
    cia.item_comment AS fulfillment_comment,
    cia.last_updated AS fulfillment_date,
    fufusr.display_name AS fulfillerusername,
    fufusr.unique_user_id AS fulfilleruserid,
        CASE
            WHEN cri.fulfiller_type::text = 'GROUP'::text THEN sgrp.name
            WHEN cri.fulfiller_type::text = 'USER'::text THEN susr.display_name
            ELSE NULL::character varying
        END AS assigned_fulfiller
   FROM resource_request_item rri
     JOIN resource_request rr ON rr.id = rri.resource_request_id
     LEFT JOIN resource_request_item_step rris ON rris.resource_request_item_id = rri.id
     LEFT JOIN suser requser ON requser.unique_user_id::text = rr.unique_requester_id::text AND requser.effective = true
     LEFT JOIN suser recipuser ON recipuser.unique_user_id::text = rri.unique_recipient_id::text AND recipuser.effective = true
     LEFT JOIN spermission perm ON perm.unique_permission_id::text = rri.unique_item_id::text AND perm.effective = true AND rri.item_type::text = 'PERMISSION'::text
     LEFT JOIN role_policy role ON role.unique_policy_id::text = rri.unique_item_id::text AND role.deleted = false AND rri.item_type::text = 'TECHNICAL_ROLE'::text
     LEFT JOIN application app ON app.id::character varying(255)::text = rri.unique_item_id::text AND rri.item_type::text = 'APPLICATION'::text
     LEFT JOIN data_source ds ON ds.id = app.id AND ds.deleted = false
     LEFT JOIN fulfillment_item_combined fic ON fic.id = rri.change_request_item_id
     LEFT JOIN change_request_item cri ON cri.id = fic.id
     LEFT JOIN change_item_action cia ON cia.id = cri.latest_action
     LEFT JOIN suser fufusr ON cia.fulfiller_id::text = fufusr.unique_user_id::text AND fufusr.effective = true
     LEFT JOIN resource_request_approval_step rras ON rras.id = rris.approval_step_id
     LEFT JOIN suser stepuser ON stepuser.unique_user_id::text = rras.finished_by::text AND stepuser.effective = true
     LEFT JOIN suser stepuser2 ON stepuser2.unique_user_id::text = rris.status_set_by::text AND stepuser2.effective = true
     LEFT JOIN suser apprvuser ON apprvuser.unique_user_id::text = rri.status_changed_by::text AND apprvuser.effective = true AND rras.id IS NOT NULL
     LEFT JOIN sgroup sgrp ON sgrp.unique_group_id::text = cri.fulfiller::text AND sgrp.effective = true
     LEFT JOIN suser susr ON susr.unique_user_id::text = cri.fulfiller::text AND susr.effective = true;

ALTER TABLE request_lifecycle_v
  OWNER TO igops;
GRANT ALL ON TABLE request_lifecycle_v TO igops;
GRANT SELECT ON TABLE request_lifecycle_v TO ig_report_role;
